# Postleid

Skript zum Korrigieren von Postleitzahlen in Excel-Dateien

Bisher werden Postleitzahlenregeln für 83 Länder,
darunter Belgien, Deutschland, Österreich und die Schweiz,
unterstützt (siehe CHANGELOG.md und countries.txt).
Die Unterstützung weiterer Länder ist in Arbeit.
